@@ -1,4 +1,4 @@
-__version__ = (0, 7)
+__version__ = (0, 8)
 
 import email.utils
 import hashlib
@@ -29,6 +29,9 @@ class UploadCare(UploaderMixin):
     def __init__(self, pub_key, secret, timeout=5,
                  api_base='http://api.uploadcare.com/',
                  upload_base='http://upload.uploadcare.com/',
+                 verify_api_ssl=True,
+                 verify_upload_ssl=True,
+                 custom_headers=None,
                  api_version='0.2'):
         self.pub_key = pub_key
         self.secret = secret
@@ -37,6 +40,10 @@ class UploadCare(UploaderMixin):
         self.api_base = api_base
         self.upload_base = upload_base
 
+        self.verify_api_ssl = verify_api_ssl
+        self.verify_upload_ssl = verify_upload_ssl
+        self.custom_headers = custom_headers
+
         self._api_parts = urlparse.urlsplit(api_base)
 
         self.api_version = api_version
@@ -45,7 +52,9 @@ class UploadCare(UploaderMixin):
         else:
             self.accept = 'application/vnd.uploadcare-v{}+json'.format(
                                 api_version)
-        self.user_agent = 'pyuploadcare/{}.{}'.format(*__version__)
+        self.default_headers = {
+            'User-Agent': 'pyuploadcare/{}.{}'.format(*__version__),
+        }
 
     def file(self, file_serialized):
         m = uuid_regex.search(file_serialized)
@@ -80,12 +89,20 @@ class UploadCare(UploaderMixin):
         ])
         return base + path
 
+    def _build_headers(self, headers=None):
+        result = dict(self.default_headers)
+        if headers is not None:
+            result.update(headers)
+        if self.custom_headers is not None:
+            result.update(self.custom_headers)
+        return result
+
     def make_request(self, verb, path, data=None):
 
         path = self._build_api_path(path)
         content = ''
 
-        if data:
+        if data is not None:
             content = json.dumps(data)
 
         content_type = 'application/json'
@@ -104,23 +121,39 @@ class UploadCare(UploaderMixin):
                         sign_string,
                         hashlib.sha1).hexdigest()
 
-        headers = {
-            'Authentication': 'UploadCare %s:%s' % (self.pub_key, sign),
+
+        # TODO: remove this when bugs are fixed and api is deployed to production
+        if self.api_version == '0.1':
+            auth_header_name = 'Authentication'
+        else:
+            auth_header_name = 'Authorization'
+
+        headers = self._build_headers({
+            auth_header_name: 'UploadCare {}:{}'.format(self.pub_key, sign),
             'Date': date,
             'Content-Type': content_type,
             'Content-Length': str(len(content)),
             'Accept': self.accept,
-            'User-Agent': self.user_agent,
-        }
-
-        logger.debug('sent: %s %s %s' % (verb, path, content))
+        })
+        logger.debug('''sent:
+            verb: {}
+            path: {}
+            headers: {}
+            data: {}'''.format(verb, path, headers, content))
 
         uri = self._build_api_uri(path)
         response = requests.request(verb, uri, allow_redirects=True,
-                                    headers=headers)
+                                    verify=self.verify_api_ssl,
+                                    headers=headers, data=content)
 
         logger.debug('got: %s %s' % (response.status_code, response.content))
 
+        if 'warning' in response.headers:
+            match = re.search('"(.+)"', response.headers['warning'])
+            if match:
+                for warning in match.group(1).split('; '):
+                    logger.warn('API Warning: {}'.format(warning))
+
         if response.status_code == 200: # Ok
             if response.json is None:
                 raise ValueError('no json in response')
@@ -129,4 +162,4 @@ class UploadCare(UploaderMixin):
         if response.status_code == 204: # No Content
             return
 
-        raise UploadCareException(response, data)
+        raise UploadCareException(response, response.content)
