@@ -19,7 +19,10 @@ settings = {
     'secret': None,
     'api_url': 'http://api.uploadcare.com/',
     'upload_url': 'http://upload.uploadcare.com/',
-    'api_version': '0.2'
+    'verify_api_ssl': True,
+    'verify_upload_ssl': False,
+    'api_version': '0.2',
+    'custom_headers': None,
 }
 
 
@@ -29,7 +32,10 @@ def create_ucare():
         secret=settings['secret'],
         api_base=settings['api_url'],
         upload_base=settings['upload_url'],
-        api_version=settings['api_version']
+        verify_api_ssl=settings['verify_api_ssl'],
+        verify_upload_ssl=settings['verify_upload_ssl'],
+        api_version=settings['api_version'],
+        custom_headers=settings['custom_headers'],
     )
 
 
@@ -129,10 +135,25 @@ def get_args():
                         help='Upload API url, can be read from uploadcare.ini'
                              ' and ~/.uploadcare config files.'
                              ' default: http://upload.uploadcare.com/')
+    parser.add_argument('--verify_upload_ssl',
+                        action='store_true',
+                        help='Verify ssl certificate of upload API url.'
+                             ' Can be read from uploadcare.ini'
+                             ' and ~/.uploadcare config files.')
+    parser.add_argument('--verify_api_ssl',
+                        action='store_true',
+                        help='Verify ssl certificate of API url.'
+                             ' Can be read from uploadcare.ini'
+                             ' and ~/.uploadcare config files.')
     parser.add_argument('--api_version',
                     help='API version, can be read from uploadcare.ini'
                              ' and ~/.uploadcare config files.'
                              ' default: 0.2')
+    parser.add_argument('-H', '--header',
+                        help='Add custom HTTP headers, can be set several times.'
+                             ' header_name:value.'
+                             ' i.e. "ucare -H User-Agent:ie5 list"',
+                        action='append')
 
     args = parser.parse_args()
     return args
@@ -155,10 +176,15 @@ def load_config_from_file(filename):
 
 def load_config_from_args(args):
     for name in settings.keys():
-        arg = getattr(args, name)
+        arg = getattr(args, name, None)
         if arg is not None:
             settings[name] = arg
-
+    custom_headers = {}
+    if args.header is not None:
+        for header in args.header:
+            name, _, value = header.partition(':')
+            custom_headers[name] = value
+    settings['custom_headers'] = custom_headers
 
 def main():
     args = get_args()
